# Generated by Django 5.0.7 on 2025-01-16 06:32

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("testapp", "0002_modelwithoutrelatednameonfieldandmeta_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ModelWithGetOrNoneManagerModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("my_field", models.BooleanField(default=False)),
            ],
        ),
    ]
